package cz.muni.consumption

import android.app.AlertDialog
import android.content.Intent
import android.os.Build
import android.os.Bundle
import android.view.MenuItem
import androidx.appcompat.app.AppCompatActivity
import com.google.android.material.tabs.TabLayoutMediator
import cz.muni.consumption.data.Play
import cz.muni.consumption.database.FirebaseProxy
import cz.muni.consumption.databinding.ActivityRoundBinding
import cz.muni.consumption.ui.playSession.round.ViewPagerAdapter


class RoundActivity : AppCompatActivity() {
    lateinit var binding: ActivityRoundBinding

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        binding = ActivityRoundBinding.inflate(layoutInflater)
        supportActionBar?.setDisplayHomeAsUpEnabled(true)
        setContentView(binding.root)

        val viewPager = binding.viewPager
        val tabLayout = binding.tabLayout

        val adapter = ViewPagerAdapter(supportFragmentManager, lifecycle)
        viewPager.adapter = adapter

        TabLayoutMediator(tabLayout, viewPager) { tab, position ->
            tab.text = "Round " + adapter.getRoundNumber(position)
        }.attach()

        val play = if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.TIRAMISU) {
            intent.getParcelableExtra("play", Play::class.java)
        } else {
            intent.getParcelableExtra("play")
        }

        if (play != null) {
            for (i in 0 until play.rounds.size) {
                adapter.addFragment(play)
            }
            if (play.rounds.size == 0) {
                adapter.addFragmentNewRound(play)
            }
        }

        binding.newRoundButton.setOnClickListener {
            if (play != null) {
                adapter.addFragmentNewRound(play)
            }
        }

        binding.finishGameButton.setOnClickListener {

            AlertDialog.Builder(this)
                .setTitle("Finish game")
                .setMessage("After you finish the game, you cannot edit the score any more. Do you want to finish the game?")
                /*.setIcon(R.drawable.ic_dialog_alert)*/
                .setPositiveButton(
                    "Yes"
                ) { _, _ ->
                    if (play != null) {
                        play.finished = true
                        FirebaseProxy.setPlayFinished(play.id, true)
                    }
                    val i = Intent(applicationContext, MainActivity::class.java)
                    startActivity(i)
                }
                .setNegativeButton("No", null).show()
        }
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        if (item.itemId == android.R.id.home) {
            onBackPressedDispatcher.onBackPressed()
            return true
        }
        return super.onOptionsItemSelected(item)
    }

}