package cz.muni.consumption.data

import android.os.Parcelable
import kotlinx.parcelize.Parcelize
import java.util.*

@Parcelize
data class Play(
    var id: String,
    val gameId: String,
    val gameName: String,
    var players: MutableList<Player>,
    val rounds: MutableList<Round>,
    val gameDate: Date,
    val scoreSubtract: Boolean,
    val scoreValue: Int,
    var finished: Boolean
) : Parcelable {

    constructor() : this(
        id = "0",
        gameId = "0",
        gameName = "",
        players = mutableListOf(),
        rounds = mutableListOf(),
        gameDate = Date(),
        scoreSubtract = false,
        scoreValue = 0,
        finished = false
    )

    constructor(gameId: String, gameName: String, scoreSubtract: Boolean, scoreValue: Int) : this(
        id = "",
        gameId = gameId,
        gameName = gameName,
        players = mutableListOf(),
        rounds = mutableListOf(),
        gameDate = Date(),
        scoreSubtract = scoreSubtract,
        scoreValue = scoreValue,
        finished = false
    )

    fun addPlayer(player: Player) {
        if (!players.contains(player))
            players.add(player)
    }

    fun removePlayer(player: Player) {
        players.remove(player)
    }

    override fun equals(other: Any?): Boolean {
        if (this === other) return true
        if (javaClass != other?.javaClass) return false

        other as Play

        if (gameId != other.gameId) return false
        if (gameName != other.gameName) return false
        if (players != other.players) return false
        if (rounds != other.rounds) return false
        if (gameDate != other.gameDate) return false
        if (finished != other.finished) return false
        return true
    }

    override fun hashCode(): Int {
        var result = gameId.hashCode()
        result = 31 * result + gameName.hashCode()
        result = 31 * result + players.hashCode()
        result = 31 * result + rounds.hashCode()
        result = 31 * result + gameDate.hashCode()
        result = 31 * result + finished.hashCode()
        return result
    }

}