package cz.muni.consumption.ui.games

import android.annotation.SuppressLint
import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.recyclerview.widget.DiffUtil
import androidx.recyclerview.widget.ListAdapter
import androidx.recyclerview.widget.RecyclerView
import cz.muni.consumption.data.Game
import cz.muni.consumption.databinding.ItemGameOverviewBinding

class GamesAdapter(
    private val onItemClick: (Game) -> Unit,
) : ListAdapter<Game, GamesViewHolder>(GamesDiffUtil()) {

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): GamesViewHolder =
        GamesViewHolder(
            ItemGameOverviewBinding
                .inflate(LayoutInflater.from(parent.context), parent, false)
        )

    override fun onBindViewHolder(holder: GamesViewHolder, position: Int) {
        val item = getItem(position)
        holder.bind(item, onItemClick)
    }
}

class GamesViewHolder(
    private val binding: ItemGameOverviewBinding
) : RecyclerView.ViewHolder(binding.root) {

    @SuppressLint("SetTextI18n")
    fun bind(item: Game, onItemClick: (Game) -> Unit) {
        binding.gameName.text = item.name
        binding.noOfPlayersValueTextView.text = item.minPlayers.toString() + "-" + item.maxPlayers.toString()
        binding.timeDurationValueTextView.text = item.minTime.toString() + "-" + item.maxTime.toString()
        binding.cardTypeValue.text = item.cardType
        binding.descriptionTextView.text = item.description
        binding.noOfPlayersTextView.text = "Number of players:"
        binding.timeDurationTextView.text = "Time duration (in minutes):"
        binding.root.setOnClickListener {
            onItemClick(item)
        }
    }
}

class GamesDiffUtil : DiffUtil.ItemCallback<Game>() {

    override fun areItemsTheSame(oldItem: Game, newItem: Game): Boolean =
        oldItem.id == newItem.id

    override fun areContentsTheSame(oldItem: Game, newItem: Game): Boolean =
        oldItem == newItem

}