package cz.muni.consumption.ui.games

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import androidx.fragment.app.Fragment
import androidx.navigation.fragment.findNavController
import androidx.recyclerview.widget.LinearLayoutManager
import cz.muni.consumption.database.FirebaseProxy
import cz.muni.consumption.databinding.FragmentGamesBinding

class GamesFragment : Fragment() {

    private lateinit var binding: FragmentGamesBinding

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View {
        binding = FragmentGamesBinding.inflate(layoutInflater, container, false)
        return binding.root
    }

    private val adapter: GamesAdapter by lazy {
        GamesAdapter(
            onItemClick = { game ->
                findNavController()
                    .navigate(GamesFragmentDirections.actionGamesFragmentToGameDetailFragment(game = game))
            },
        )
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        removeBackButton()

        binding.recyclerView.layoutManager = LinearLayoutManager(context)
        binding.recyclerView.adapter = adapter

        binding.btnAdd.setOnClickListener {
            findNavController()
                .navigate(
                    GamesFragmentDirections.actionGamesFragmentToGameDetailAddEditFragment()
                )
        }
    }

    private fun refreshList() {
        FirebaseProxy.getGames(
            success = { games ->
                adapter.submitList(games.reversed())
            },
            fail = {
                Toast.makeText(context, "Server error", Toast.LENGTH_SHORT).show()
            }
        )
    }

    override fun onResume() {
        super.onResume()
        removeBackButton()
        refreshList()
    }

    private fun removeBackButton() {
        val activity = requireActivity()
        if (activity is AppCompatActivity) {
            activity.supportActionBar?.setDisplayHomeAsUpEnabled(false)
        }
    }
}