package cz.muni.consumption.ui.games.detail

import android.app.AlertDialog
import android.content.DialogInterface
import android.content.Intent
import android.graphics.BitmapFactory
import android.os.Bundle
import android.view.*
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import androidx.fragment.app.Fragment
import androidx.navigation.fragment.findNavController
import androidx.navigation.fragment.navArgs
import cz.muni.consumption.R
import cz.muni.consumption.data.Game
import cz.muni.consumption.database.FirebaseProxy
import cz.muni.consumption.databinding.FragmentGameDetailBinding
import java.io.File

class GameDetailFragment : Fragment() {

    private lateinit var binding: FragmentGameDetailBinding
    private val args: GameDetailFragmentArgs by navArgs()
    private lateinit var game: Game

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View {
        binding = FragmentGameDetailBinding.inflate(layoutInflater, container, false)
        return binding.root
    }

    override fun onCreateOptionsMenu(menu: Menu, inflater: MenuInflater) {
        menu.clear()
        inflater.inflate(R.menu.menu_game_detail, menu)
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        when (item.itemId) {
            R.id.action_edit -> {
                findNavController()
                    .navigate(
                        GameDetailFragmentDirections.actionGameDetailFragmentToGameDetailAddEditFragment(
                            game = game
                        )
                    )
                return true
            }
            R.id.action_delete -> {
                AlertDialog.Builder(context)
                    .setTitle("Delete game")
                    .setMessage("Do you want to delete the game permanently?")
                    .setPositiveButton(
                        "Yes",
                        DialogInterface.OnClickListener { _, _ ->
                            Toast.makeText(
                                requireContext(),
                                "${game.name} was successfully deleted",
                                Toast.LENGTH_SHORT
                            ).show()
                            FirebaseProxy.deleteGame(game.id)
                            findNavController().navigateUp()
                        })
                    .setNegativeButton("No", null).show()
            }
        }
        return false
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        setHasOptionsMenu(true)
        setInitialValues()
    }

    override fun onViewStateRestored(savedInstanceState: Bundle?) {
        super.onViewStateRestored(savedInstanceState)
        setImage(game.id)
    }

    private fun setInitialValues() {
        val actionBar = (activity as AppCompatActivity).supportActionBar
        game = args.game  // game not nullable

        actionBar?.title = game.name
        binding.noOfPlayersValueTextView.text = "${game.minPlayers} - ${game.maxPlayers}"
        binding.timeDurationValueTextView.text = "${game.minTime}-${game.maxTime}"
        binding.cardtypeValueTextView.text = game.cardType
        binding.descriptionTextView.text = game.description
        binding.rulesValueTextView.text = game.rules
        binding.scoringValueTextView.text = if (game.scoreSubtract) "Decreasing" else "Increasing"
        binding.decreaseFrom.text = game.scoreValue.toString()

        setImage(game.id)
    }

    private fun setImage(gameId: String) {
        val localFile = File.createTempFile("tempImage", "jpg")
        val imageRef = FirebaseProxy.getImageRef(gameId)

        imageRef.metadata.addOnSuccessListener {
            // Image exists, download it
            imageRef.getFile(localFile).addOnCompleteListener {
                val bitmap = BitmapFactory.decodeFile(localFile.absolutePath)
                binding.imageview.setImageBitmap(bitmap)
            }.addOnFailureListener {
                Toast.makeText(context, "Failed to load image.", Toast.LENGTH_SHORT).show()
                binding.imageview.setImageResource(R.drawable.default_game_image)
            }
        }.addOnFailureListener {
            // Image doesn't exist, set a default image
            binding.imageview.setImageResource(R.drawable.default_game_image)
        }
    }
}
