package cz.muni.consumption.ui.play

import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.recyclerview.widget.DiffUtil
import androidx.recyclerview.widget.ListAdapter
import androidx.recyclerview.widget.RecyclerView
import cz.muni.consumption.data.Play
import cz.muni.consumption.databinding.ItemGamePlayBinding
import java.text.SimpleDateFormat
import java.util.*
import kotlin.collections.ArrayList

class PlayAdapter(
    private val onItemClick: (Play) -> Unit,
) : ListAdapter<Play, PlayViewHolder>(PlayDiffUtil()) {

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): PlayViewHolder =
        PlayViewHolder(
            ItemGamePlayBinding
                .inflate(LayoutInflater.from(parent.context), parent, false)
        )

    override fun onBindViewHolder(holder: PlayViewHolder, position: Int) {
        val item = getItem(position)
        holder.bind(item, onItemClick)
    }
}

class PlayViewHolder(
    private val binding: ItemGamePlayBinding
) : RecyclerView.ViewHolder(binding.root) {

    fun bind(item: Play, onItemClick: (Play) -> Unit) {
        val score = ArrayList<Int>(Collections.nCopies(item.players.size, item.scoreValue))
        item.rounds.forEach {
            for (i in score.indices) {
                if (!item.scoreSubtract) {
                    score[i] += it.score[i]
                } else {
                    score[i] -= it.score[i]
                }
            }
        }
        binding.gameName.text = item.gameName
        binding.dateTextView.text = SimpleDateFormat("dd. MM. yyyy", Locale.getDefault()).format(item.gameDate)
        binding.playersTextView.text = item.players.joinToString(", ") { it.username }
        binding.scoreTextView.text = score.toString().replace("[", "").replace("]", "")
        binding.root.setOnClickListener {
            onItemClick(item)
        }
    }
}

class PlayDiffUtil : DiffUtil.ItemCallback<Play>() {

    override fun areItemsTheSame(oldItem: Play, newItem: Play): Boolean =
        oldItem.id == newItem.id

    override fun areContentsTheSame(oldItem: Play, newItem: Play): Boolean =
        oldItem == newItem

}