package cz.muni.consumption.ui.play

import android.content.Intent
import android.os.Bundle
import android.view.*
import android.widget.Toast
import androidx.fragment.app.Fragment
import androidx.navigation.fragment.findNavController
import androidx.recyclerview.widget.LinearLayoutManager
import com.google.firebase.auth.FirebaseAuth
import cz.muni.consumption.R
import cz.muni.consumption.RoundActivity
import cz.muni.consumption.RoundUneditableActivity
import cz.muni.consumption.SignInActivity
import cz.muni.consumption.database.FirebaseProxy
import cz.muni.consumption.databinding.FragmentPlayBinding

class PlayFragment : Fragment() {

    private lateinit var binding: FragmentPlayBinding

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        binding = FragmentPlayBinding.inflate(layoutInflater, container, false)
        return binding.root
    }

    private val adapter: PlayAdapter by lazy {
        PlayAdapter(
            onItemClick = { play ->
                val currentFirebaseUser = FirebaseAuth.getInstance().currentUser
                val id = currentFirebaseUser?.uid

                if (!play.finished && play.players.size > 0 && id == play.players[0].id) {
                    val intent = Intent(activity, RoundActivity::class.java)
                    intent.putExtra("play", play)
                    startActivity(intent)
                }
                else {
                    val intent = Intent(activity, RoundUneditableActivity::class.java)
                    intent.putExtra("playId", play.id)
                    startActivity(intent)
                }
            },
        )
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        setHasOptionsMenu(true)

        binding.recyclerView.layoutManager = LinearLayoutManager(context)
        binding.recyclerView.adapter = adapter

        binding.playGameButton.setOnClickListener {
            findNavController()
                .navigate(
                    PlayFragmentDirections.actionPlayFragmentToSelectGameFragment()
                )
        }

        binding.playJoinButton.setOnClickListener {
            findNavController()
                .navigate(
                    PlayFragmentDirections.actionPlayFragmentToJoinPlayFragment()
                )
        }
    }

    override fun onCreateOptionsMenu(menu: Menu, inflater: MenuInflater) {
        inflater.inflate(R.menu.menu_main_options, menu)
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        // Handle menu item clicks
        return when (item.itemId) {
            R.id.action_logout -> {
                FirebaseAuth.getInstance().signOut()
                val intent = Intent(activity, SignInActivity::class.java)
                startActivity(intent)
                return true
            }
            else -> super.onOptionsItemSelected(item)
        }
    }

    private fun refreshList() {
        FirebaseProxy.getPlays(
            success = { plays ->
                adapter.submitList(plays.reversed())
            },
            fail = {
                Toast.makeText(context, "Server error", Toast.LENGTH_SHORT).show()
            }
        )
    }

    override fun onResume() {
        super.onResume()
        refreshList()
    }
}