package cz.muni.consumption.ui.playSession.joinPlay

import android.content.ClipDescription.MIMETYPE_TEXT_PLAIN
import android.content.ClipboardManager
import android.content.Context
import android.os.Bundle
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import androidx.fragment.app.Fragment
import androidx.navigation.fragment.findNavController
import com.google.firebase.auth.FirebaseAuth
import cz.muni.consumption.data.Player
import cz.muni.consumption.database.FirebaseProxy
import cz.muni.consumption.databinding.FragmentJoinPlayBinding


class JoinPlayFragment : Fragment() {
    private lateinit var binding: FragmentJoinPlayBinding
    lateinit var currentUser : Player

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        binding = FragmentJoinPlayBinding.inflate(layoutInflater, container, false)
        return binding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val actionBar = (activity as AppCompatActivity).supportActionBar
        actionBar?.title = "Join game"

        val currentFirebaseUser = FirebaseAuth.getInstance().currentUser
        val id = currentFirebaseUser?.uid
        if (id == null) {
            Toast.makeText(context, "Server error fetching current user", Toast.LENGTH_SHORT).show()
        } else {
            selectPlayer(id)
        }

        binding.btnPaste.setOnClickListener {
            val clipboard =
                requireContext().getSystemService(Context.CLIPBOARD_SERVICE) as ClipboardManager
            var pasteData = ""

            if (clipboard.hasPrimaryClip()) {
                val clip = clipboard.primaryClip
                if (clip!!.description.hasMimeType(MIMETYPE_TEXT_PLAIN))
                    pasteData = clip!!.getItemAt(0).text.toString()
            }

            if (!TextUtils.isEmpty(pasteData))
                binding.editGameCode.setText(pasteData)

        }

        binding.btnJoin.setOnClickListener {
            val code = binding.editGameCode.text.toString()

            FirebaseProxy.existsInitPlay(
                code,
                success = { play ->
                        FirebaseProxy.putPlayerToInitPlay(code, currentUser)
                        findNavController().navigate(JoinPlayFragmentDirections.actionJoinPlayFragmentToWaitPlayFragment(initPlay = play))
                },
                fail = {
                    Toast.makeText(context, "Could not join game with provided token", Toast.LENGTH_SHORT).show()
                }
            )
        }
    }

    private fun selectPlayer(id: String) {
        FirebaseProxy.getPlayer(
            id,
            success = { player ->
                currentUser = player
            },
            fail = {
                Toast.makeText(context, "Server error", Toast.LENGTH_SHORT).show()
            }
        )
    }

}