package cz.muni.consumption.ui.playSession.joinPlay

import android.content.Intent
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import androidx.fragment.app.Fragment
import androidx.navigation.fragment.findNavController
import androidx.navigation.fragment.navArgs
import com.google.firebase.auth.FirebaseAuth
import com.google.firebase.database.*
import cz.muni.consumption.RoundUneditableActivity
import cz.muni.consumption.data.InitPlay
import cz.muni.consumption.data.Player
import cz.muni.consumption.database.FirebaseProxy
import cz.muni.consumption.databinding.FragmentWaitPlayBinding

class WaitPlayFragment : Fragment() {
    private lateinit var binding: FragmentWaitPlayBinding
    private val args: WaitPlayFragmentArgs by navArgs()
    private lateinit var play: InitPlay
    lateinit var currentUser: Player

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        binding = FragmentWaitPlayBinding.inflate(layoutInflater, container, false)
        return binding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        play = args.initPlay

        val actionBar = (activity as AppCompatActivity).supportActionBar
        actionBar?.title = play.gameName

        val currentFirebaseUser = FirebaseAuth.getInstance().currentUser
        val id = currentFirebaseUser?.uid
        if (id == null) {
            Toast.makeText(context, "Server error fetching current user", Toast.LENGTH_SHORT).show()
        } else {
            selectPlayer(id)
        }

        setPlayListener()

    }

    private fun setPlayListener() {
        val databaseRef: DatabaseReference = FirebaseDatabase.getInstance().reference
        val databaseInitPlaysRef: DatabaseReference = databaseRef.child("InitPlays")
        val playRef = databaseInitPlaysRef.child(play.id)

        playRef.addValueEventListener(object : ValueEventListener {
            override fun onDataChange(dataSnapshot: DataSnapshot) {
                if (dataSnapshot.exists() && dataSnapshot.value != null) {
                    // InitPlay was changed, is initializing finished?
                    val initPlay = dataSnapshot.getValue(InitPlay::class.java)
                    if (initPlay?.playId?.isNotEmpty() == true) {
                        // play was already created, players are final
                        val players = initPlay.players
                        if (players.containsKey(currentUser.id)) {
                            Toast.makeText(context, "Player found in play", Toast.LENGTH_SHORT).show()
                            FirebaseProxy.getPlay(
                                initPlay.playId,
                                onSuccess = { play ->
                                    val intent = Intent(activity, RoundUneditableActivity::class.java)
                                    intent.putExtra("playId", play.id)
                                    startActivity(intent)
                                    findNavController().popBackStack(
                                        findNavController().graph.startDestinationId, false
                                    )
                                },
                                onFail = {
                                    Toast.makeText(context, "Server error", Toast.LENGTH_SHORT).show()
                                })
                        } else {
                            // currentUser is not a player in the game
                            Toast.makeText(context, "Sorry, you were removed from the play by play creator.", Toast.LENGTH_SHORT).show()
                            findNavController().navigateUp()
                        }

                    }
                }
            }

            override fun onCancelled(error: DatabaseError) {
            }
        })
    }

    private fun selectPlayer(id: String) {
        FirebaseProxy.getPlayer(
            id,
            success = { player ->
                currentUser = player
            },
            fail = {
                Toast.makeText(context, "Server error", Toast.LENGTH_SHORT).show()
            }
        )
    }

}