package cz.muni.consumption.ui.playSession.round

import android.text.Editable
import android.text.TextWatcher
import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.recyclerview.widget.DiffUtil
import androidx.recyclerview.widget.ListAdapter
import androidx.recyclerview.widget.RecyclerView
import cz.muni.consumption.data.RoundScores
import cz.muni.consumption.database.FirebaseProxy
import cz.muni.consumption.databinding.ItemRoundScoreBinding


class RoundAdapter(
    private val onItemClick: (RoundScores) -> Unit,
) : ListAdapter<RoundScores, RoundViewHolder>(RoundDiffUtil()) {

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RoundViewHolder =
        RoundViewHolder(
            ItemRoundScoreBinding.inflate(LayoutInflater.from(parent.context), parent, false)
        )

    override fun onBindViewHolder(holder: RoundViewHolder, position: Int) {
        val item = getItem(position)
        holder.bind(item, onItemClick)
    }
}

class RoundViewHolder(
    private val binding: ItemRoundScoreBinding
) : RecyclerView.ViewHolder(binding.root) {


    fun bind(item: RoundScores, onItemClick: (RoundScores) -> Unit) {
        if (item.play.rounds.isNotEmpty()) {
            var score = item.play.scoreValue
            for (i in 0 ..item.roundNumber) {
                if (!item.play.scoreSubtract) {
                    score += item.play.rounds[i].score[item.playerNumber]
                }
                else {
                    score -= item.play.rounds[i].score[item.playerNumber]
                }
            }
            binding.totalScore.text = score.toString()
            binding.cardName.text = item.play.players[item.playerNumber].username
            binding.editText.setText(item.play.rounds[item.roundNumber].score[item.playerNumber].toString())
        }
        if (binding.editText.text.toString() == "0") {
            binding.editText.setText("")
        }
        binding.root.setOnClickListener {
            onItemClick(item)
        }
        binding.editText.clearTextChangedListeners()
        binding.editText.addTextChangedListener(object : TextWatcher {
            override fun afterTextChanged(s: Editable) {}
            override fun beforeTextChanged(s: CharSequence, start: Int, count: Int, after: Int) {}
            override fun onTextChanged(s: CharSequence, start: Int, before: Int, count: Int) {
                try {
                    if (s.isNotEmpty()) {
                        item.play.rounds[item.roundNumber].score[item.playerNumber] =
                            Integer.parseInt(s.toString())

                        var score = item.play.scoreValue
                        for (i in 0 ..item.roundNumber) {
                            if (!item.play.scoreSubtract) {
                                score += item.play.rounds[i].score[item.playerNumber]
                            }
                            else {
                                score -= item.play.rounds[i].score[item.playerNumber]
                            }
                        }

                        binding.totalScore.text = score.toString()
                    } else {
                        binding.totalScore.text = item.play.scoreValue.toString()
                        item.play.rounds[item.roundNumber].score[item.playerNumber] = 0
                    }
                } catch (e: java.lang.NumberFormatException) {
                    binding.totalScore.text = item.play.scoreValue.toString()
                    binding.editText.setText("")
                    item.play.rounds[item.roundNumber].score[item.playerNumber] = 0
                }
                if (binding.editText.text.toString() == "0") {
                    binding.editText.setText("")
                }

                FirebaseProxy.updatePlayRoundScores(
                    item.play.id,
                    item.play.rounds[item.roundNumber],
                    item.roundNumber
                );
            }
        })
    }
}


class RoundDiffUtil : DiffUtil.ItemCallback<RoundScores>() {

    override fun areItemsTheSame(oldItem: RoundScores, newItem: RoundScores): Boolean =
        oldItem.playerNumber == newItem.playerNumber
                && oldItem.roundNumber == newItem.roundNumber
                && oldItem.play == newItem.play

    override fun areContentsTheSame(oldItem: RoundScores, newItem: RoundScores): Boolean =
        oldItem == newItem

}
