package cz.muni.consumption.ui.playSession.round

import android.app.AlertDialog
import android.content.DialogInterface
import android.content.Intent
import android.os.Bundle
import android.view.*
import android.widget.Toast
import androidx.fragment.app.Fragment
import androidx.navigation.fragment.findNavController
import androidx.recyclerview.widget.LinearLayoutManager
import cz.muni.consumption.MainActivity
import cz.muni.consumption.R
import cz.muni.consumption.data.Play
import cz.muni.consumption.data.RoundScores
import cz.muni.consumption.database.FirebaseProxy
import cz.muni.consumption.databinding.FragmentRoundBinding

class RoundFragment : Fragment() {
    private lateinit var binding: FragmentRoundBinding
    private var roundNumber: Int = 0
    private var play = Play()

    fun setParameters(aPlay: Play, aRoundNum: Int) {
        play = aPlay
        roundNumber = aRoundNum
    }

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        binding = FragmentRoundBinding.inflate(layoutInflater, container, false)
        return binding.root
    }

    private val roundPlayerAdapter: RoundAdapter by lazy {
        RoundAdapter(
            onItemClick = {
            }
        )
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        setHasOptionsMenu(true)

        binding.scoreRecyclerView.layoutManager = LinearLayoutManager(context)
        binding.scoreRecyclerView.adapter = roundPlayerAdapter
    }

    override fun onCreateOptionsMenu(menu: Menu, inflater: MenuInflater) {
        menu.clear()
        inflater.inflate(R.menu.menu_actionbar_round, menu)
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        when (item.itemId) {
            R.id.action_delete -> {


                AlertDialog.Builder(context)
                    .setTitle("Delete play")
                    .setMessage("Do you want to delete the play permanently?")
                    .setPositiveButton(
                        "Yes",
                        DialogInterface.OnClickListener { _, _ ->
                            FirebaseProxy.deletePlay(play.id)

                            val intent = Intent(activity, MainActivity::class.java)
                            startActivity(intent)
                            findNavController().popBackStack(
                                findNavController().graph.startDestinationId, false
                            )

                            Toast.makeText(context, "Play successfully deleted", Toast.LENGTH_SHORT).show()
                        })
                    .setNegativeButton("No", null).show()
            }
        }
        return false
    }

    private fun refreshList() {
        val roundScores = mutableListOf<RoundScores>()
        for (i in 0 until play.players.size) {
            roundScores.add(RoundScores(roundNumber, i, play))
        }
        roundPlayerAdapter.submitList(roundScores)
    }

    override fun onResume() {
        super.onResume()
        refreshList()
    }
}