package cz.muni.consumption.ui.playSession.round

import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.recyclerview.widget.DiffUtil
import androidx.recyclerview.widget.ListAdapter
import androidx.recyclerview.widget.RecyclerView
import cz.muni.consumption.data.RoundScores
import cz.muni.consumption.databinding.ItemRoundScoreBinding


class RoundUneditableAdapter(
    private val onItemClick: (RoundScores) -> Unit,
) : ListAdapter<RoundScores, RoundUneditableViewHolder>(RoundUneditableDiffUtil()) {

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RoundUneditableViewHolder =
        RoundUneditableViewHolder(
            ItemRoundScoreBinding.inflate(LayoutInflater.from(parent.context), parent, false)
        )

    override fun onBindViewHolder(holder: RoundUneditableViewHolder, position: Int) {
        val item = getItem(position)
        holder.bind(item, onItemClick)
    }
}

class RoundUneditableViewHolder(
    private val binding: ItemRoundScoreBinding
) : RecyclerView.ViewHolder(binding.root) {
    fun bind(item: RoundScores, onItemClick: (RoundScores) -> Unit) {
        if (item.play.rounds.isNotEmpty()) {
            var score = item.play.scoreValue
            for (i in 0 ..item.roundNumber) {
                if (!item.play.scoreSubtract) {
                    score += item.play.rounds[i].score[item.playerNumber]
                }
                else {
                    score -= item.play.rounds[i].score[item.playerNumber]
                }
            }
            binding.totalScore.text = score.toString()
            binding.cardName.text = item.play.players[item.playerNumber].username
            binding.editText.setText(item.play.rounds[item.roundNumber].score[item.playerNumber].toString())
        }
//        binding.root.setOnClickListener {
//            onItemClick(item)
//        }
        binding.editText.isEnabled = false
    }
}


class RoundUneditableDiffUtil : DiffUtil.ItemCallback<RoundScores>() {

    override fun areItemsTheSame(oldItem: RoundScores, newItem: RoundScores): Boolean =
        oldItem.playerNumber == newItem.playerNumber
                && oldItem.roundNumber == newItem.roundNumber
                && oldItem.play.rounds[oldItem.roundNumber].score[oldItem.playerNumber] == newItem.play.rounds[newItem.roundNumber].score[newItem.playerNumber]
                && oldItem.play == newItem.play

    override fun areContentsTheSame(oldItem: RoundScores, newItem: RoundScores): Boolean =
        oldItem == newItem

}
