package cz.muni.consumption.ui.playSession.round

import androidx.fragment.app.Fragment
import androidx.fragment.app.FragmentManager
import androidx.lifecycle.Lifecycle
import androidx.viewpager2.adapter.FragmentStateAdapter
import cz.muni.consumption.data.Play
import cz.muni.consumption.data.Round
import cz.muni.consumption.database.FirebaseProxy

//https://medium.com/busoft/how-to-use-viewpager2-with-tablayout-in-android-eaf5b810ef7c


class ViewPagerAdapter(fragmentManager: FragmentManager, lifecycle: Lifecycle) :
    FragmentStateAdapter(fragmentManager, lifecycle) {
    private val mFragments: MutableList<Fragment> = ArrayList()
    private val mFragmentNumbers: MutableList<Int> = ArrayList()

    override fun getItemCount(): Int {
        return mFragments.size
    }

    fun getRoundNumber(position: Int): Int {
        if (position < mFragmentNumbers.size) {
            return mFragmentNumbers[position]
        }
        return 0
    }

    fun addFragment(play: Play) {
        val fragment = RoundFragment()
        if (mFragmentNumbers.size == 0) {
            mFragmentNumbers.add(0)
        } else {
            mFragmentNumbers.add(mFragmentNumbers.last() + 1)
        }

        fragment.setParameters(play, mFragmentNumbers.last())
        mFragments.add(fragment)
        notifyDataSetChanged()
    }

    fun addFragmentNewRound(play: Play) {
        val fragment = RoundFragment()
        if (mFragmentNumbers.size == 0) {
            mFragmentNumbers.add(0)
        } else {
            mFragmentNumbers.add(mFragmentNumbers.last() + 1)
        }

        val roundScores = mutableListOf<Int>()
        for (i in 0 until play.players.size) {
            roundScores.add(0)
        }
        play.rounds.add(Round(play.rounds.size, roundScores))
        FirebaseProxy.updateRounds(play.id, play.rounds)


        fragment.setParameters(play, mFragmentNumbers.last())
        mFragments.add(fragment)
        notifyDataSetChanged()
    }

    fun deleteFragment(position: Int) {
        mFragments.removeAt(position)
        mFragmentNumbers.removeAt(position)
        notifyDataSetChanged()
    }

    override fun createFragment(position: Int): Fragment {
        return mFragments[position]
    }
}