package cz.muni.consumption.ui.playSession.selectGame

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import androidx.core.widget.addTextChangedListener
import androidx.fragment.app.Fragment
import androidx.navigation.fragment.findNavController
import androidx.recyclerview.widget.LinearLayoutManager
import cz.muni.consumption.database.FirebaseProxy
import cz.muni.consumption.databinding.FragmentSelectGameBinding
import cz.muni.consumption.ui.games.GamesAdapter

class SelectGameFragment : Fragment() {
    private lateinit var binding: FragmentSelectGameBinding

    private val adapter: GamesAdapter by lazy {
        GamesAdapter(
            onItemClick = { game ->
                findNavController()
                    .navigate(SelectGameFragmentDirections.actionSelectGameFragmentToSelectPlayersFragment(game = game))
            },
        )
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View {
        binding = FragmentSelectGameBinding.inflate(layoutInflater, container, false)
        return binding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        binding.playerList.layoutManager = LinearLayoutManager(context)
        binding.playerList.adapter = adapter
        
        binding.editSelectGame.addTextChangedListener {
            refreshList()
        }
    }

    private fun refreshList() {
        FirebaseProxy.getGames(
            success = { games ->
                adapter.submitList((games.filter { game ->
                    game.name.contains(
                        binding.editSelectGame.text,
                        ignoreCase = true
                    )
                }).reversed())
            },
            fail = {
                Toast.makeText(context, "Server error", Toast.LENGTH_SHORT).show()
            }
        )
    }

    override fun onResume() {
        super.onResume()
        refreshList()
    }
}