package cz.muni.consumption.ui.playSession.selectPlayers
import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.recyclerview.widget.DiffUtil
import androidx.recyclerview.widget.ListAdapter
import androidx.recyclerview.widget.RecyclerView
import com.google.firebase.auth.FirebaseAuth
import cz.muni.consumption.data.Player
import cz.muni.consumption.databinding.ItemSelectPlayerBinding

class PlayerAdapter (
    private val playerList: MutableList<Player>,
    private val onPlayerChecked: (Player, Boolean) -> Unit
    ): ListAdapter<Player, PlayerViewHolder>(PlayerDiffUtil()) {

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): PlayerViewHolder =
        PlayerViewHolder(
            ItemSelectPlayerBinding
                .inflate(LayoutInflater.from(parent.context), parent, false)
        )

    override fun onBindViewHolder(holder: PlayerViewHolder, position: Int) {
        val item = playerList[position]
        holder.bind(item, onPlayerChecked)
    }

    override fun getItemCount(): Int {
        return playerList.size
    }
}

class PlayerViewHolder(private val binding: ItemSelectPlayerBinding) :
    RecyclerView.ViewHolder(binding.root) {

    fun bind(player: Player, onPlayerChecked: (Player, Boolean) -> Unit) {
        binding.playerUsername.text = player.username
        binding.playerCheckbox.isChecked = true

        val currentUser = FirebaseAuth.getInstance().currentUser
        val id = currentUser?.uid
        if (id != null && id == player.id) {
            binding.playerCheckbox.isClickable = false
            binding.playerCheckbox.isFocusable = false
            binding.playerCheckbox.isEnabled = false
        }

        binding.playerCheckbox.setOnCheckedChangeListener { _, isChecked ->
            onPlayerChecked(player, isChecked)
        }
    }
}

class PlayerDiffUtil : DiffUtil.ItemCallback<Player>() {

    override fun areItemsTheSame(oldItem: Player, newItem: Player): Boolean =
        oldItem.id == newItem.id && oldItem.username == newItem.username

    override fun areContentsTheSame(oldItem: Player, newItem: Player): Boolean =
        oldItem == newItem
}